@@ -3,7 +3,9 @@ import maya
 import typer
 
 from humanfriendly import format_timespan
+from rich import print
 from togglwrapper import Toggl
+from typing import Optional
 
 from .__version__ import __version__
 
@@ -11,6 +13,12 @@ from .__version__ import __version__
 cli = typer.Typer()
 
 
+def version_callback(value: bool):
+    if value:
+        print(f"toggl-standup version: {__version__}")
+        raise typer.Exit()
+
+
 @cli.command()
 def main(
     slang_date: str,
@@ -18,7 +26,9 @@ def main(
     show_duration: bool = False,
     show_time: bool = False,
     timezone: str = "US/Central",
-    version: bool = False,
+    version: Optional[bool] = typer.Option(
+        None, "--version", callback=version_callback
+    ),
 ):
     """
     Standup tool to help with Toggl
@@ -26,7 +36,7 @@ def main(
     toggl = Toggl(api_key)
 
     if version:
-        typer.echo(__version__)
+        print(__version__)
         raise typer.Exit()
 
     now = maya.when(slang_date, timezone=timezone)
@@ -51,7 +61,8 @@ def main(
             stop_slag = None
 
         if start_slag != last_start_slang:
-            typer.echo(crayons.green("## {0}".format(start.slang_date())))
+            print(f"[bold green]## {start.slang_date()}[/bold green]")
+
         last_start_slang = start_slag
 
         project_id = time_entry.get("pid")
@@ -80,7 +91,7 @@ def main(
         if not show_duration:
             del cmd[-1]
 
-        typer.echo(" ".join(cmd))
+        print(" ".join(cmd))
 
 
 if __name__ == "__main__":
